From bc8c2c57880523472b30f475d566a8133e2d2e20 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Sat, 21 May 2011 14:04:51 -0400
Subject: [PATCH] - Fix s/pattern/prefix/ in clear_cache()

---
 program/include/html.php |  122 +++++++++++++++++++++++-----------------
 1 files changed, 70 insertions(+), 52 deletions(-)

diff --git a/program/include/html.php b/program/include/html.php
index 99132a1..8f932ce 100644
--- a/program/include/html.php
+++ b/program/include/html.php
@@ -4,8 +4,8 @@
  +-----------------------------------------------------------------------+
  | program/include/html.php                                              |
  |                                                                       |
- | This file is part of the RoundCube Webmail client                     |
- | Copyright (C) 2005-2009, RoundCube Dev, - Switzerland                 |
+ | This file is part of the Roundcube Webmail client                     |
+ | Copyright (C) 2005-2010, The Roundcube Dev Team                       |
  | Licensed under the GNU GPL                                            |
  |                                                                       |
  | PURPOSE:                                                              |
@@ -34,13 +34,12 @@
 
     public static $lc_tags = true;
     public static $common_attrib = array('id','class','style','title','align');
-    public static $containers = array('iframe','div','span','p','h1','h2','h3',
-	'form','textarea','table','tr','th','td','style','script');
+    public static $containers = array('iframe','div','span','p','h1','h2','h3','form','textarea','table','thead','tbody','tr','th','td','style','script');
 
     /**
      * Constructor
      *
      * @param array Hash array with tag attributes
      */
     public function __construct($attrib = array())
     {
@@ -64,19 +63,22 @@
     /**
      * Generic method to create a HTML tag
      *
      * @param string Tag name
      * @param array  Tag attributes as key/value pairs
      * @param string Optinal Tag content (creates a container tag)
      * @param array  List with allowed attributes, omit to allow all
      * @return string The XHTML tag
      */
     public static function tag($tagname, $attrib = array(), $content = null, $allowed_attrib = null)
     {
+        if (is_string($attrib))
+            $attrib = array('class' => $attrib);
+
         $inline_tags = array('a','span','img');
         $suffix = $attrib['nl'] || ($content && $attrib['nl'] !== false && !in_array($tagname, $inline_tags)) ? "\n" : '';
 
         $tagname = self::$lc_tags ? strtolower($tagname) : $tagname;
-        if ($content || in_array($tagname, self::$containers)) {
+        if (isset($content) || in_array($tagname, self::$containers)) {
             $templ = $attrib['noclose'] ? "<%s%s>%s" : "<%s%s>%s</%s>%s";
             unset($attrib['noclose']);
             return sprintf($templ, $tagname, self::attrib_string($attrib, $allowed_attrib), $content, $tagname, $suffix);
@@ -89,8 +91,8 @@
     /**
      * Derrived method for <div> containers
      *
-     * @param mixed  Hash array with tag attributes or string with class name
-     * @param string Div content
+     * @param mixed  $attr Hash array with tag attributes or string with class name
+     * @param string $cont Div content
      * @return string HTML code
      * @see html::tag()
      */
@@ -105,8 +107,8 @@
     /**
      * Derrived method for <p> blocks
      *
-     * @param mixed  Hash array with tag attributes or string with class name
-     * @param string Paragraph content
+     * @param mixed  $attr Hash array with tag attributes or string with class name
+     * @param string $cont Paragraph content
      * @return string HTML code
      * @see html::tag()
      */
@@ -121,7 +123,7 @@
     /**
      * Derrived method to create <img />
      *
-     * @param mixed Hash array with tag attributes or string with image source (src)
+     * @param mixed $attr Hash array with tag attributes or string with image source (src)
      * @return string HTML code
      * @see html::tag()
      */
@@ -137,8 +139,8 @@
     /**
      * Derrived method for link tags
      *
-     * @param mixed  Hash array with tag attributes or string with link location (href)
-     * @param string Link content
+     * @param mixed  $attr Hash array with tag attributes or string with link location (href)
+     * @param string $cont Link content
      * @return string HTML code
      * @see html::tag()
      */
@@ -148,14 +150,14 @@
             $attr = array('href' => $attr);
         }
         return self::tag('a', $attr, $cont, array_merge(self::$common_attrib,
-	    array('href','target','name','onclick','onmouseover','onmouseout','onmousedown','onmouseup')));
+	    array('href','target','name','rel','onclick','onmouseover','onmouseout','onmousedown','onmouseup')));
     }
 
     /**
      * Derrived method for inline span tags
      *
-     * @param mixed  Hash array with tag attributes or string with class name
-     * @param string Tag content
+     * @param mixed  $attr Hash array with tag attributes or string with class name
+     * @param string $cont Tag content
      * @return string HTML code
      * @see html::tag()
      */
@@ -170,8 +172,8 @@
     /**
      * Derrived method for form element labels
      *
-     * @param mixed  Hash array with tag attributes or string with 'for' attrib
-     * @param string Tag content
+     * @param mixed  $attr Hash array with tag attributes or string with 'for' attrib
+     * @param string $cont Tag content
      * @return string HTML code
      * @see html::tag()
      */
@@ -186,7 +188,7 @@
     /**
      * Derrived method to create <iframe></iframe>
      *
-     * @param mixed Hash array with tag attributes or string with frame source (src)
+     * @param mixed $attr Hash array with tag attributes or string with frame source (src)
      * @return string HTML code
      * @see html::tag()
      */
@@ -213,8 +215,8 @@
     /**
      * Create string with attributes
      *
      * @param array Associative arry with tag attributes
      * @param array List of allowed attributes
      * @return string Valid attribute string
      */
     public static function attrib_string($attrib = array(), $allowed = null)
@@ -269,8 +271,13 @@
     protected $type = 'text';
     protected $allowed = array('type','name','value','size','tabindex',
 	'autocomplete','checked','onchange','onclick','disabled','readonly',
-	'spellcheck','results','maxlength','src');
+	'spellcheck','results','maxlength','src','multiple');
 
+    /**
+     * Object constructor
+     *
+     * @param array $attrib Associative array with tag attributes
+     */
     public function __construct($attrib = array())
     {
         if (is_array($attrib)) {
@@ -289,8 +296,8 @@
     /**
      * Compose input tag
      *
      * @param string Field value
      * @param array Additional attributes to override
      * @return string HTML output
      */
     public function show($value = null, $attrib = null)
@@ -335,7 +342,7 @@
     /**
      * Constructor
      *
      * @param array Named tag attributes
      */
     public function __construct($attrib = null)
     {
@@ -347,7 +354,7 @@
     /**
      * Add a hidden field to this instance
      *
      * @param array Named tag attributes
      */
     public function add($attrib)
     {
@@ -381,8 +388,8 @@
     /**
      * Get HTML code for this object
      *
      * @param string Value of the checked field
      * @param array Additional attributes to override
      * @return string HTML output
      */
     public function show($value = '', $attrib = null)
@@ -411,8 +418,8 @@
     /**
      * Get HTML code for this object
      *
      * @param string Value of the checked field
      * @param array Additional attributes to override
      * @return string HTML output
      */
     public function show($value = '', $attrib = null)
@@ -443,8 +450,8 @@
     /**
      * Get HTML code for this object
      *
      * @param string Textbox value
      * @param array Additional attributes to override
      * @return string HTML output
      */
     public function show($value = '', $attrib = null)
@@ -497,13 +504,13 @@
     protected $tagname = 'select';
     protected $options = array();
     protected $allowed = array('name','size','tabindex','autocomplete',
-	'multiple','onchange','disabled');
+	'multiple','onchange','disabled','rel');
     
     /**
      * Add a new option to this drop-down
      *
-     * @param mixed Option name or array with option names
-     * @param mixed Option value or array with option values
+     * @param mixed $names  Option name or array with option names
+     * @param mixed $values Option value or array with option values
      */
     public function add($names, $values = null)
     {
@@ -517,12 +524,11 @@
         }
     }
 
-
     /**
      * Get HTML code for this object
      *
      * @param string Value of the selection option
      * @param array Additional attributes to override
      * @return string HTML output
      */
     public function show($select = array(), $attrib = null)
@@ -563,7 +569,11 @@
     private $rowindex = 0;
     private $colindex = 0;
 
-
+    /**
+     * Constructor
+     *
+     * @param array $attrib Named tag attributes
+     */
     public function __construct($attrib = array())
     {
         $this->attrib = array_merge($attrib, array('summary' => '', 'border' => 0));
@@ -572,8 +582,8 @@
     /**
      * Add a table cell
      *
-     * @param array Cell attributes
-     * @param string Cell content
+     * @param array  $attr Cell attributes
+     * @param string $cont Cell content
      */
     public function add($attr, $cont)
     {
@@ -596,8 +606,8 @@
     /**
      * Add a table header cell
      *
-     * @param array Cell attributes
-     * @param string Cell content
+     * @param array  $attr Cell attributes
+     * @param string $cont Cell content
      */
     public function add_header($attr, $cont)
     {
@@ -637,11 +647,10 @@
         }
     }
 
-
     /**
      * Jump to next row
      *
-     * @param array Row attributes
+     * @param array $attr Row attributes
      */
     public function add_row($attr = array())
     {
@@ -655,7 +664,7 @@
     /**
      * Set current row attrib
      *
-     * @param array Row attributes
+     * @param array $attr Row attributes
      */
     public function set_row_attribs($attr = array())
     {
@@ -668,7 +677,7 @@
     /**
      * Build HTML output of the table data
      *
      * @param array Table attributes
      * @return string The final table HTML code
      */
     public function show($attrib = null)
@@ -718,6 +727,15 @@
     {
       return count($this->rows);
     }
+
+    /**
+     * Remove table body (all rows)
+     */
+    public function remove_body()
+    {
+        $this->rows     = array();
+        $this->rowindex = 0;
+    }
+
 }
 
-?>
@@ -34,13 +34,12 @@
      * Constructor
      *
-     * @param array Hash array with tag attributes
+     * @param array $attrib Hash array with tag attributes
      */
     public function __construct($attrib = array())
@@ -64,19 +63,22 @@
      * Generic method to create a HTML tag
      *
-     * @param string Tag name
-     * @param array  Tag attributes as key/value pairs
-     * @param string Optinal Tag content (creates a container tag)
-     * @param array  List with allowed attributes, omit to allow all
+     * @param string $tagname Tag name
+     * @param array  $attrib  Tag attributes as key/value pairs
+     * @param string $content Optinal Tag content (creates a container tag)
+     * @param array  $allowed_attrib List with allowed attributes, omit to allow all
      * @return string The XHTML tag
      */
@@ -213,8 +215,8 @@
      * Create string with attributes
      *
-     * @param array Associative arry with tag attributes
-     * @param array List of allowed attributes
+     * @param array $attrib Associative arry with tag attributes
+     * @param array $allowed List of allowed attributes
      * @return string Valid attribute string
      */
@@ -289,8 +296,8 @@
      * Compose input tag
      *
-     * @param string Field value
-     * @param array Additional attributes to override
+     * @param string $value Field value
+     * @param array  $attrib Additional attributes to override
      * @return string HTML output
      */
@@ -335,7 +342,7 @@
      * Constructor
      *
-     * @param array Named tag attributes
+     * @param array $attrib Named tag attributes
      */
     public function __construct($attrib = null)
@@ -347,7 +354,7 @@
      * Add a hidden field to this instance
      *
-     * @param array Named tag attributes
+     * @param array $attrib Named tag attributes
      */
     public function add($attrib)
@@ -381,8 +388,8 @@
      * Get HTML code for this object
      *
-     * @param string Value of the checked field
-     * @param array Additional attributes to override
+     * @param string $value  Value of the checked field
+     * @param array  $attrib Additional attributes to override
      * @return string HTML output
      */
@@ -411,8 +418,8 @@
      * Get HTML code for this object
      *
-     * @param string Value of the checked field
-     * @param array Additional attributes to override
+     * @param string $value  Value of the checked field
+     * @param array  $attrib Additional attributes to override
      * @return string HTML output
      */
@@ -443,8 +450,8 @@
      * Get HTML code for this object
      *
-     * @param string Textbox value
-     * @param array Additional attributes to override
+     * @param string $value  Textbox value
+     * @param array  $attrib Additional attributes to override
      * @return string HTML output
      */
@@ -517,12 +524,11 @@
      * Get HTML code for this object
      *
-     * @param string Value of the selection option
-     * @param array Additional attributes to override
+     * @param string $select Value of the selection option
+     * @param array  $attrib Additional attributes to override
      * @return string HTML output
      */
@@ -668,7 +677,7 @@
      * Build HTML output of the table data
      *
-     * @param array Table attributes
+     * @param array $attrib Table attributes
      * @return string The final table HTML code
      */

--
Gitblit v1.9.1